<%@ Control Language="c#" AutoEventWireup="True" CodeBehind="ACSExtensions.ascx.cs" Inherits="umbraco.ACSExtensions.ACSExtensions" TargetSchema="http://schemas.microsoft.com/intellisense/ie5" %>

<asp:PlaceHolder ID="Settings" runat="server" Visible="true">
    
    <!-- Federation box -->
    <div class="tab main-tabinfo">
        <div class="container">
            <h1>Access Control Services Extensions Configuration</h1>
            <p>
                The Access Control Service Extensions for Umbraco augment your web site with powerful identity and access management capabilities:
            </p>
            <div>
                <ul style="list-style:square inside;">
                    <li>Authenticate users from social identity providers such as Facebook, Windows Live ID, Google and Yahoo. Manage those users and access policies though the familiar Umbraco management UI, without the hassle of maintaining passwords for them!</li>
                    <li>Make your web site available to business federated partners from Active Directory or any other identity provider with federation capabilities. Apply fine-grained access policies mapping claims to your existing Member Groups.</li>
                    <li>Handle user invitations via a powerful email invitation &amp; verification system.</li>
                </ul>
            </div>
            <div style="padding-top: 10px;">
                <b>Important: In order to use the Access Control Service Extensions for Umbraco, you need to have an ACS namespace.</b> If you dont have a namespace yet, you can apply for one at <a target="_blank" href="https://windows.azure.com/">https://windows.azure.com/</a>
            </div>
        </div>

        <!-- federation -->
        <div class="federation-hold">
            <form action="#">
                <fieldset>
                    <div class="step">
                        <div class="container">
                            <p>
                                <strong>Do you want to configure Federation for your websites?</strong>
                            </p>
                            <ul class="mini-tabset">
                                <li class="btn-yes"><a href="#federation-step1" class="federation-tab"><span>yes</span></a></li>
                                <li class="btn-no">
                                    <asp:LinkButton runat="server" OnClick="GotoNextStep" CssClass="SkipACSExtensionsConfiguration">
                                        <span>no</span>
                                    </asp:LinkButton>
                                </li>
                            </ul>
                        </div>
                    </div>

                    <!-- step1 -->
                    <div id="federation-step1">
                        <div class="step">
                            <div class="container">
                                <%--ACS settings--%>
                                <p class="instructionText">
                                    <strong>Access Control Service Settings</strong><br />
                                    Enter your ACS namespace and the URL at which your Umbraco instance is deployed. The management key is optional, but if you dont enter most of the extension features will not be available. You can obtain the namespace management key at <a target="_blank" href="https://{namespace}.accesscontrol.windows.net/v2/mgmt/web/ServiceAccount/ManagementKey/Edit">https://{namespace}.accesscontrol.windows.net/v2/mgmt/web/ServiceAccount/ManagementKey/Edit</a>
                                </p>
                                <div class="instruction-hold federationPanel">
                                    <div class="row acs" runat="server" id="AcsNamespaceItem">
                                        <asp:Label runat="server" AssociatedControlID="AcsNamespace" ID="AcsNamespaceLabel">Namespace:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="AcsNamespace" />
                                        </span>
                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="AcsNamespaceRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="AcsNamespace" />
                                    </div>
                                    
                                    <div class="row acs" runat="server" id="AcsManagementKeyItem">
                                        <asp:Label runat="server" AssociatedControlID="AcsManagementKey" ID="AcsManagementKeyLabel">Management Key:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="AcsManagementKey" ClientIDMode="Static" />
                                        </span>
                                        <label>&nbsp;<tt>(optional)</tt></label>
                                    </div>

                                    <div class="row acs" runat="server" id="AcsRealmAddressItem">
                                        <asp:Label runat="server" AssociatedControlID="AcsRealmAddress" ID="AcsRealmAddressLabel">Umbraco URL:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="AcsRealmAddress" />
                                        </span>
                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="AcsRealmAddressRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="AcsRealmAddress" />
                                    </div>
                                </div>

                                <%--Social Identity Providers settings--%>
                                <p class="instructionText">
                                    <strong>Social Identity Providers</strong><br />
                                    Use the controls below to decide from which social identity providers you want to accept users from. This feature requires you to enter your ACS namespace management key in the text field above.
                                </p>
                                <div class="instruction-hold socialIdentityProvidersPanel">
                                    <div class="row acs" runat="server" id="AcsSocialIdentityProvidersItem">
                                        <div style="float: left;">
                                            <div class="socialIdentityProvider">
                                                <p>
                                                    <asp:CheckBoxList runat="server" ClientIDMode="Static" ID="AcsSocialIdentityProviders" RepeatDirection="Horizontal">
                                                        <asp:ListItem Selected="True" Value="Windows Live ID" />
                                                        <asp:ListItem Selected="True" Value="Google" />
                                                        <asp:ListItem Selected="True" Value="Yahoo!" />
                                                    </asp:CheckBoxList>
                                                    <span style="padding:0px 6px 0px 0px;">
                                                        <asp:CheckBox ClientIDMode="Static" ID="FacebookIdentityProviderCheckBox" runat="server" Text="Facebook" Checked="false" />
                                                    </span>
                                                </p>
                                            </div>
                                            <div id="FacebookAppSettings">
                                                <fieldset>
                                                    <div class="row acs facebook" runat="server" id="FacebookAppIdItem">
                                                        <asp:Label runat="server" AssociatedControlID="FacebookAppId" ID="FacebookAppIdLabel">Application ID:</asp:Label>
                                                        <span>
                                                            <asp:TextBox runat="server" CssClass="text federation" ID="FacebookAppId" />
                                                        </span>
                                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="FacebookAppIdRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="FacebookAppId" />
                                                    </div>
                                                    <div class="row acs facebook" runat="server" id="FacebookAppSecretItem">
                                                        <asp:Label runat="server" AssociatedControlID="FacebookAppSecret" ID="FacebookAppSecretLabel">Application Secret:</asp:Label>
                                                        <span>
                                                            <asp:TextBox runat="server" CssClass="text federation" ID="FacebookAppSecret" />
                                                        </span>
                                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="FacebookAppSecretRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="FacebookAppSecret" />
                                                    </div>
                                                </fieldset>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <%--SMTP settings--%>
                                <p class="instructionText">
                                    <strong>SMTP Settings</strong><br />
                                    Users from social identity providers are invited to gain access to your web site via email. The process is fully automated and integrated with the Members management UI in Umbraco. In order to use the social provider integration feature you need to configure a SMTP server.
                                </p>
                                <div class="instruction-hold federationPanel">
                                    <div class="row smtp" runat="server" id="SmtpServerNameItem">
                                        <asp:Label runat="server" AssociatedControlID="SmtpServerName" ID="SmtpServerNameLabel">Server Name:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="SmtpServerName" />
                                        </span>
                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="SmtpServerNameRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="SmtpServerName" />
                                    </div>
                                    
                                    <div class="row smtp" runat="server" id="SmtpPortItem">
                                        <asp:Label runat="server" AssociatedControlID="SmtpPort" ID="SmtpPortLabel">Port:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="SmtpPort" Text="25" />
                                        </span>
                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="SmtpPortRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="SmtpPort" />
                                    </div>

                                    <div class="row smtp" runat="server" id="SmtpUserItem">
                                        <asp:Label runat="server" AssociatedControlID="SmtpUser" ID="SmtpUserLabel">User:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="SmtpUser" />
                                        </span>
                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="SmtpUserRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="SmtpUser" />
                                    </div>

                                    <div class="row smtp" runat="server" id="SmtpPasswordItem">
                                        <asp:Label runat="server" AssociatedControlID="SmtpUser" ID="SmtpPasswordLabel">Password:</asp:Label>
                                        <span>
                                            <asp:TextBox runat="server" CssClass="text federation" ID="SmtpPassword" TextMode="Password" />
                                        </span>
                                        <asp:RequiredFieldValidator EnableClientScript="true" CssClass="requiredFieldValidator" ID="SmtpPasswordRequiredFieldValidator" runat="server" ErrorMessage="*" ControlToValidate="SmtpPassword" />
                                    </div>
                                </div>
                            </div>

                            <!-- btn box -->
                            <footer class="btn-box">
							    <div class="t">&nbsp;</div>
								<asp:LinkButton runat="server" class="btn-install" OnClick="SaveFederationConfiguration"><!--single-tab submit btn-install-->
                                    <span>install</span>
                                </asp:LinkButton>
							</footer>
                        </div>
                    </div>
                </fieldset>
            </form>
        </div>
    </div>

    <script type="text/javascript">
        jQuery(document).ready(function () {
            jQuery('.federation-hold').each(function () {
                var list = $(this);
                var links = list.find('a.federation-tab');

                links.each(function () {
                    var link = $(this);
                    var href = link.attr('href');
                    var tab = jQuery(href);

                    if (link.hasClass('active'))
                        tab.show();
                    else
                        tab.hide();

                    link.click(function () {
                        links.filter('.active').each(function () {
                            jQuery(jQuery(this).removeClass('active').attr('href')).hide();
                        });

                        link.addClass('active');
                        tab.show();

                        return false;
                    });
                });
            });

            $(".federation").each(function () {
                $(this).data("val", "");
            });

            enableSocialIdentityProvidersPanel();
            $("#AcsManagementKey").change(function () {
                enableSocialIdentityProvidersPanel();
            });

            showHideFacebookAppSettings();
            $("#FacebookIdentityProviderCheckBox").click(function () {
                jQuery("#FacebookAppSettings").slideToggle(500);
                enableValidators();
            });

            $(".SkipACSExtensionsConfiguration").click(function () {
                ValidatorEnable(document.getElementById('<%= AcsNamespaceRequiredFieldValidator.ClientID %>'), false);
                ValidatorEnable(document.getElementById('<%= AcsRealmAddressRequiredFieldValidator.ClientID %>'), false);

                ValidatorEnable(document.getElementById('<%= FacebookAppIdRequiredFieldValidator.ClientID %>'), false);
                ValidatorEnable(document.getElementById('<%= FacebookAppSecretRequiredFieldValidator.ClientID %>'), false);

                ValidatorEnable(document.getElementById('<%= SmtpServerNameRequiredFieldValidator.ClientID %>'), false);
                ValidatorEnable(document.getElementById('<%= SmtpPortRequiredFieldValidator.ClientID %>'), false);
                ValidatorEnable(document.getElementById('<%= SmtpUserRequiredFieldValidator.ClientID %>'), false);
                ValidatorEnable(document.getElementById('<%= SmtpPasswordRequiredFieldValidator.ClientID %>'), false);
            });
        });

        function enableSocialIdentityProvidersPanel() {
            if ($('#AcsManagementKey').val() == "") {
                $('.socialIdentityProvidersPanel :input').attr('disabled', 'disabled');
            }
            else {
                $('.socialIdentityProvidersPanel :input').attr('disabled', '');
            }

            // Disable Windows Live ID always
            // $("#AcsSocialIdentityProviders_0").attr('disabled', 'disabled');
        }

        function showHideFacebookAppSettings() {
            if ($("#FacebookIdentityProviderCheckBox").is(':checked')) {
                jQuery("#FacebookAppSettings").show();
            }
            else {
                jQuery("#FacebookAppSettings").hide();
            }

            enableValidators();
        }

        function enableValidators(enabled) {
            var enable = ($("#FacebookIdentityProviderCheckBox").is(':checked') && ($("#FacebookIdentityProviderCheckBox").is(':disabled') == false));

            ValidatorEnable(document.getElementById('<%= FacebookAppIdRequiredFieldValidator.ClientID %>'), enable);
            ValidatorEnable(document.getElementById('<%= FacebookAppSecretRequiredFieldValidator.ClientID %>'), enable);
        }
	</script>

    <style media="screen" type="text/css">
        .requiredFieldValidator
        {
            background: none !important;
            color: #FFFFFF !important;
            width: 10px !important;
        }
        
        .socialIdentityProvider       
        {
            /*float: left;*/
        }
        
        .socialIdentityProvider td
        {
            padding-bottom: 5px;
        }
        
        .socialIdentityProvider span
        {
            background: none !important;
            color: #FFFFFF !important;
            float: none !important;
        }
        
        .socialIdentityProvider label
        {
            width: auto !important;
            color: #FFFFFF !important;
            font-weight: normal !important;
            float: none !important;
            padding: 0px 10px 0 0  !important;
        }
        
        .socialIdentityProvider input
        {
            vertical-align: top !important;
            float: none !important;
        }
        
        .federationPanel
        {
            padding: 2px 0 15px !important;
        }
        
        .facebook span
        {
            width: auto !important;
        }
        
        #FacebookAppSettings
        {
            padding-top: 4px;
        }
        
        #FacebookAppSettings fieldset
        {
            padding: 5px !important;
            width: 470px !important;
        }
    </style>

</asp:PlaceHolder>

<asp:PlaceHolder ID="Installing" runat="server" Visible="false">
    <!-- installing umbraco -->
    <div class="tab install-tab" id="federation-tab">
        <div class="container">
            <h1>Configuring Federation</h1>
            <p>
                Federation was configured successfully.
            </p>

            <%--<div class="loader">
                <div class="hold">
                    <div class="progress-bar">
                    </div>
                    <span class="progress-bar-value">0%</span>
                </div>
                <strong></strong>
            </div>--%>

        </div>
        
        <!-- btn box -->
        <footer class="btn-box" style="display: none;">
			<div class="t">&nbsp;</div>
			 <asp:LinkButton class="btn-step btn btn-continue" runat="server" OnClick="GotoNextStep"><span>Continue</span></asp:LinkButton>
             <asp:LinkButton class="btn-step btn btn-back" style="display: none;" runat="server"><span>Back</span></asp:LinkButton>
		</footer>
    </div>

    <script type="text/javascript">
        var intervalId = 0;

        jQuery(document).ready(function () {
            intervalId = setInterval("progressBarCallback()", 1000);
            jQuery('.btn-box').hide();
            jQuery.ajax({
                type: 'POST',
                contentType: 'application/json; charset=utf-8',
                data: '{}',
                dataType: 'json',
                url: 'utills/p.aspx/installOrUpgrade'
            });
        });

        function progressBarCallback() {
            jQuery.getJSON('utills/p.aspx?feed=progress', function (data) {

                updateProgressBar(data.percentage);
                updateStatusMessage(data.message)

                if (data.error != "") {
                    clearInterval(intervalId);
                    updateStatusMessage(data.error);

                    jQuery(".loader .hold").hide();

                    jQuery(".btn-continue").hide();
                    jQuery(".btn-back").show();
                    jQuery(".btn-box").show();
                }

                if (data.percentage == 100) {
                    clearInterval(intervalId);
                    jQuery(".btn-box").show();
                    jQuery('.ui-progressbar-value').css("background-image", "url(../umbraco_client/installer/images/pbar.gif)");
                }
            });
        }
	</script>
</asp:PlaceHolder>

<asp:Panel ID="Confirms" runat="server" Visible="False">
    
    <asp:PlaceHolder ID="installConfirm" runat="server" Visible="False">
        <h1>Federation configured</h1>
        <div class="success">
            <p>
                Federation configuration was completed successfully. Press <b>Continue</b> to proceed.
            </p>
        </div>
    </asp:PlaceHolder>

    <!-- btn box -->
    <footer class="btn-box" style="display: none;">
		<div class="t">&nbsp;</div>
		<asp:LinkButton class="btn-step btn btn-continue" runat="server" OnClick="GotoNextStep">
            <span>Continue</span>
        </asp:LinkButton>
	</footer>

</asp:Panel>