﻿// ----------------------------------------------------------------------------------
// Microsoft Developer & Platform Evangelism
// 
// Copyright (c) Microsoft Corporation. All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES 
// OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// ----------------------------------------------------------------------------------
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
// ----------------------------------------------------------------------------------

namespace umbraco.ACSExtensions
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    public class MappingRuleService
    {
        private readonly IMappingRuleRepository repository;

        public MappingRuleService()
            : this (new XmlMappingRuleRepository())
        { 
        }

        public MappingRuleService(IMappingRuleRepository repository)
        {
            this.repository = repository;
        }

        public MappingRule GetMappingRule(Guid id)
        {
            return this.repository.RetrieveMappingRule(id);
        }

        public IEnumerable<IdentityProviderInfo> RetrieveBusinessIdentityProviders()
        {
            return this.repository.RetrieveIdentityProviders();
        }

        public IEnumerable<MappingRule> RetrieveMappingsByMemberGroup(IdentityProviderInfo identityProvider, MemberGroupInfo memberGroup)
        {
            return this.repository.RetrieveMappingRulesByMemberGroup(identityProvider, memberGroup);
        }

        public void AddMapping(MappingRule newMapping)
        {
            if (newMapping.Id == Guid.Empty)
            {
                newMapping.Id = Guid.NewGuid();
            }

            if (string.IsNullOrWhiteSpace(newMapping.Name))
            {
                newMapping.Name = newMapping.ClaimType.Split('/').Last();
            }
            
            this.repository.AddMappingRule(newMapping);
        }

        public void EditMapping(MappingRule mapping)
        {
            this.repository.EditMappingRule(mapping);
        }

        public void DeleteMapping(Guid id)
        {
            this.repository.DeleteMappingRule(id);
        }
    }
}